<?php

use App\Http\Controllers\AdminController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\EnrollmentController;
use App\Http\Controllers\LectureController;
use App\Models\Course;
use App\Models\Lecture;
use App\Models\Setting;
use App\Models\Teacher;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

Route::get('/', function (Request $request) {
    $settings = Setting::first();

    // Fetch search inputs
    $search = $request->input('search');
    $system = $request->input('system');

    // Query courses with filters
    $courses = Course::with('teachers')
        ->when($search, function ($query, $search) {
            $query->where('name', 'LIKE', "%{$search}%")
                  ->orWhere('description', 'LIKE', "%{$search}%");
        })
        ->when($system, function ($query, $system) {
            $query->where('system', $system);
        })
        ->get();

    // Process courses with teachers
    $coursesWithTeachers = [];
    foreach ($courses as $course) {
        foreach ($course->teachers as $teacher) {
            $coursesWithTeachers[] = array_merge($course->toArray(), [
                'teacher_name' => $teacher->name,
                'teacher_id' => $teacher->id,
            ]);
        }
    }

    return view('home', [
        'courses' => $coursesWithTeachers,
        'settings' => $settings,
    ]);
})->name('home');

Route::get('/course/{teacherId}/{courseId}', function ($teacherId, $courseId) {

    $course = Course::findOrFail($courseId);
    $lectures = Lecture::with('teacher')->where('course_id', $courseId)
                       ->where('teacher_id', $teacherId)
                       ->get();
    return view('coursePage', ['course' => $course, 'lectures' => $lectures]);
})->name('coursePage');

Route::get('/course/lecture/{courseId}/{lectureId}', function ($courseId,$lectureId) {

    $course = Course::findOrFail($courseId);
    $lectures = Lecture::with('teacher')->where('id', $lectureId)->first();
    // dd(auth()->user()->student->id);
    return view('lecturePage', ['course' => $course, 'lecture' => $lectures]);
})->name('lecturePage');


Route::get('/about-us', function () {
    $settings=Setting::first();
    return view('aboutUs',['settings'=>$settings]);})->name('page.aboutUs');
    
Route::get('/contact-us', function () {return view('contactUs');})->name('contactUs');


Route::get('/login', function () {return view('login');})->name('page.login');
Route::get('/register-student', function () {return view('register');})->name('page.register');

Route::post('/login', [AuthController::class, 'login'])->name('login');
Route::post('/register-student', [AuthController::class, 'registerStudent'])->name('register.student');
Route::post('/add-teacher', [AuthController::class, 'addTeacher'])->name('add.teacher');
Route::post('/add-admin', [AuthController::class, 'addAdmin'])->name('add.admin');
Route::get('/logout', [AuthController::class, 'logout'])->name('logout');

//student
Route::get('/account/my-account', function () {return view('account_details');})->name('account.index'); 
Route::put('/account/my-account/update/{id}',[AuthController::class, 'update'])->name('auth.update');
Route::get('/account/my-courses', function () {
    $student = Auth::user()->student; // الحصول على المستخدم (الطالب)
    $lectures = $student->enrollments()->with('lecture', 'course')->get(); // جلب enrollments مع course و lecture
    return view('account-student.my-courses', compact('lectures'));
})->name('account.courses'); 
Route::get('/lecture/enroll/{lectureId}',[EnrollmentController::class, 'enrollInLecture'])->name('student.enroll');

//teacher
Route::get('/teacher/dashboard', function () {
    $teacher=Teacher::where('user_id',Auth::user()->id)->first();
    return view('teacher.dashboard',['teacher'=>$teacher]);
})->name('teacher.dashboard'); 
Route::get('/teacher/course-page/{courseId}',[LectureController::class, 'index'])->name('course.dashboard'); 
Route::post('/courses/{courseId}/lectures', [LectureController::class, 'store'])->name('lectures.store');
Route::put('/courses/{courseId}/lectures/{lectureId}', [LectureController::class, 'update'])->name('lectures.update');
Route::delete('/courses/{courseId}/lectures/{lectureId}', [LectureController::class, 'destroy'])->name('lectures.destroy');



//admin
Route::get('/admin/dashboard',[AdminController::class, 'index'])->name('admin.dashboard');
Route::get('/admin/userManagement',[AdminController::class, 'indexUserManagement'])->name('admin.user.management'); 
Route::get('/admin/settings',[AdminController::class, 'indexSettings'])->name('admin.settings'); 
Route::put('/settings', [AdminController::class, 'update'])->name('settings.update');

Route::get('/admin/teachers', [AdminController::class, 'indexTeachers'])->name('teachers.index');
Route::post('/teachers/add', [AuthController::class, 'addTeacher'])->name('teachers.add');
Route::put('/teachers/update/{id}', [AuthController::class, 'updateTeacher'])->name('teachers.update');
Route::delete('/teachers/{teacher}', [AuthController::class, 'deleteTeacher'])->name('teachers.delete');

Route::get('/admin/students', [AdminController::class, 'indexStudent'])->name('students.index');
Route::post('/students/add', [AuthController::class, 'registerStudent'])->name('students.add');
Route::put('/students/update/{id}', [AuthController::class, 'updateStudent'])->name('students.update');
Route::delete('/students/{student}', [AuthController::class, 'deleteStudents'])->name('students.delete');

Route::get('/admin/courses', [AdminController::class, 'indexCourse'])->name('course.index');
Route::post('/courses/add', [AdminController::class, 'addCourse'])->name('course.add');
Route::put('/courses/update/{id}', [AdminController::class, 'updateCourse'])->name('course.update');
Route::delete('/courses/{course}', [AdminController::class, 'deleteCourse'])->name('course.delete');
